handleNestedScroll property

bool handleNestedScroll
final

Whether to enable nested scroll handling.

When true, dragging over the sheet content does not move the sheet while the sheet is at its maximum position and the content is scrolled away from the top, so that the content can be scrolled back first.

The header and the drag handle always move the sheet, regardless of this flag.

Implementation

final bool handleNestedScroll;